stereo.tools.SpatialLag
=======================

.. currentmodule:: stereo.tools

.. autoclass:: SpatialLag

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SpatialLag.__init__
      ~SpatialLag.add_result
      ~SpatialLag.check_param
      ~SpatialLag.fit
      ~SpatialLag.get_data
      ~SpatialLag.get_genes
      ~SpatialLag.get_params
      ~SpatialLag.gm_model
      ~SpatialLag.sparse2array
   
   

   
   
   